@@ -1,7 +1,7 @@
 package Mojo::Pua;
-use Evo 'Evo::Export *; Evo::Promise *; ::Class';
+use Evo 'Evo::Export *; ::Class';
 
-our $VERSION = '0.004';    # VERSION
+our $VERSION = '0.005';    # VERSION
 use constant SINGLE => our $SINGLE
   = Mojo::Pua::Class->new(max_connections => 100);
 
@@ -30,7 +30,7 @@ Mojo::Pua - HTTP Client + Evo::Promises
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
